document.addEventListener("DOMContentLoaded", function () {
    fetchData();
    document.getElementById("nodata").style.display = "none";

    function fetchData() {
        jQuery.ajax({
            url: BMSI_object.ajax_url,
            type: 'GET',
            dataType: "JSON",
            data: {
                action: "BMSI_chart_details",
                chart_nonce: BMSI_object.nonce,
            },
            success: function (data) {
                if (Array.isArray(data) && data.length > 0) {
                    var createdates = data.map(function (entry) {
                        return entry.createdate;
                    });

                    var totals = data.map(function (entry) {
                        return entry.total;
                    });
                    var users = data.map(function (entry) {
                        return entry.user;
                    });
                    var newsletters = data.map(function (entry) {
                        return entry.newsletters;
                    });

                    renderChart(createdates, totals, users, newsletters);
                } else {
                    document.getElementById("nodata").style.display = "block";
                }
            },
            error: function (xhr, status, error) {
                console.error(error);
            }
        });
    }

    function renderChart(createdates, totals, users, newsletters) {
        var canvas = document.querySelector('#chart');
        var ctx = canvas.getContext('2d');

        var dataAvailable = createdates.length > 0;

        var myChart = new Chart(ctx, {
            type: 'bar',
            data: {
                labels: createdates,
                datasets: [
                    {
                        label: dataAvailable ? 'Total Mails' : 'No data available',
                        data: dataAvailable ? totals : [],
                        backgroundColor: 'rgba(248, 213, 126, 1)',
                        borderColor: 'rgba(248, 213, 126, 1)',
                        borderWidth: 1,
                        barThickness: 20
                    },
                    {
                        label: dataAvailable ? 'Users Mails' : 'No data available',
                        data: dataAvailable ? users : [],
                        backgroundColor: 'rgba(58, 155, 213,1)',
                        borderColor: 'rgba(58, 155, 213, 1)',
                        borderWidth: 1,
                        barThickness: 20
                    },
                    {
                        label: dataAvailable ? 'Contacts Mails' : 'No data available',
                        data: dataAvailable ? newsletters : [],
                        backgroundColor: 'rgba(248, 152, 126, 1)',
                        borderColor: 'rgba(248, 152, 126, 1)',
                        borderWidth: 1,
                        barThickness: 20
                    }
                ]
            },
            options: {
                plugins: {
                    title: {
                        display: true,
                        text: 'Total Mail Send',
                        font: {
                            size: 30,
                            color: '#212529',
                            weight: 'bold',
                            lineHeight: 1.2
                        }
                    }
                }
            }
        });
    }
});
