jQuery(document).ready(function ($) {

    // Initialize multiselect plugin
    jQuery('#tagsSelect').multiselect({
        columns: 1,
        texts: {
            placeholder: 'Select Tags',
            search: 'Search Tags'
        },
        search: true,
        selectAll: true,
        onSelectAll: function() {
            updateSelectedTags();
        },
        onUnselectAll: function() {
            updateSelectedTags();
        },
        onOptionClick: function() {
            updateSelectedTags();
        }
    });

    // Function to update selected tags and add class to #ms-list-1
    function updateSelectedTags() {
        var selectedTags = [];
        jQuery('#ms-list-1 input[type="checkbox"]:checked').each(function() {
            var tagName = jQuery(this).attr('title');
            selectedTags.push(tagName);
        });
        var buttonText = 'Select Tags';
        if (selectedTags.length > 0) {
            var currentText = jQuery('#ms-list-1 button span').text();
            if (currentText !== 'Select Tags') {
                // Append selected tags to existing text, separated by commas
                buttonText = currentText + ', ' + selectedTags.join(', ');
            } else {
                // Replace initial text with selected tags
                buttonText = selectedTags.join(', ');
            }
            jQuery('#ms-list-1').addClass('ms-has-selections'); // Add class
        } else {
            jQuery('#ms-list-1').removeClass('ms-has-selections'); // Remove class if no selections
        }
        jQuery('#ms-list-1 button span').text(buttonText);
    }

    // Get values array from the hidden input
    // var valuesArray = jQuery('#tags_data').val() != undefined ? JSON.parse(jQuery('#tags_data').val()) : "";
    // console.log(valuesArray);

    // setTimeout(function() {
    //     jQuery('#ms-list-1 input[type="checkbox"]').each(function() {
    //         var checkboxValue = jQuery(this).val();

    //         if (jQuery.inArray(checkboxValue, valuesArray) !== -1) {
    //             jQuery(this).prop('checked', true); // Check the checkbox
    //         } else {
    //             jQuery(this).prop('checked', false); // Uncheck the checkbox
    //         }
    //     });

    //     // Update selected tags initially
    //     updateSelectedTags();

    //     // Trigger change event on #tagsSelect to update multiselect display
    //     jQuery('#tagsSelect').multiselect('refresh');
    // }, 100); // Adjust the delay as needed to ensure multiselect is fully initialized

    var table = jQuery('#get_all_template').DataTable({
        "searching": true,
        "filter": true,
        "processing": true,
        "serverSide": true,
        "bInfo": false,
        "ajax": {
            "url": BMSI_object.ajax_url,
            "type": "POST",
            "data": {
                "action": "BMSI_display_template",
                "start_date": jQuery("#start").val(),
                "end_date": jQuery("#end").val(),
                "template_nonce": BMSI_object.nonce
            },
        },
        language: {
            searchPlaceholder: "Search By Name",
            sLengthMenu: "Show  _MENU_  Entries",
            search: "",
            paginate: {
                "first": "<i class='fa-solid fa-backward'></i>",
                "last": "<i class='fa-solid fa-forward'></i>",
                "next": "<i class='fa-solid fa-caret-right'></i>",
                "previous": "<i class='fa-solid fa-caret-left'></i>"
            },
        },
        "columns": [
            { "data": "id", sortable: true },
            { "data": "name", sortable: true },
            {
                data: null,
                className: "dt-center editor-edit",
                sortable: false,
                render: function (data, type, row) {
                    return '<div><a href="' + BMSI_object.admin_url + 'admin.php?page=email_builder&id=' + data.id + '" id="btn_edit" ><i class="fa-solid fa-pen-to-square"></i></a><a href="javascript:void(0);" id="btn_delete" onClick="delete_template(\'' + data.id + '\')"><i class="fas fa-trash-alt" style="margin-right:3px;"></i></a><a href="javascript:void(0);" id="btn_send_mail" onClick="send_mail(\'' + data.template_name + '\')"><i class="fa fa-paper-plane" style="margin-right:3px;"></i></a>';
                }
            }

        ],
        "paging": true,
        "pageLength": 10,
        "select": true,
        "order": [
            [1, 'asc'],
        ],
    });

    jQuery('#type_filter').on('change', function () {
        history_table.draw();

    });

    var history_table = $('#history_pro_template').DataTable({
        "searching": true,
        "filter": true,
        "processing": true,
        "serverSide": true,
        "bInfo": false,
        "ajax": {
            "url": BMSI_object.ajax_url,
            "type": "POST",
            "data": function (d) {
                d.action = "BMSI_pro_display_history";
                d.start_date = $("#start").val();
                d.end_date = $("#end").val();
                d.mail_type = $("#type_filter").val();
                d.pro_history_nonce = BMSI_object.nonce;
            },
        },
        language: {
            searchPlaceholder: "Search By Name",
            sLengthMenu: "Show  _MENU_  Entries",
            search: "",
            paginate: {
                "first": "<i class='fa-solid fa-backward'></i>",
                "last": "<i class='fa-solid fa-forward'></i>",
                "next": "<i class='fa-solid fa-caret-right'></i>",
                "previous": "<i class='fa-solid fa-caret-left'></i>"
            },
        },
        "columns": [
            { "data": "from_name", sortable: true },
            { "data": "subject", sortable: true },
            { "data": "type", sortable: true },
            { "data": "createdate", sortable: true },
            {
                "data": "open",
                sortable: false,
                render: function (data, type, row) {
                    return data + ' times read';
                }
            },
            {
                data: null,
                className: "dt-center editor-edit",
                sortable: false,
                render: function (data, type, row) {
                    return '<div><a href="javascript:void(0);" data-bs-target="#exampleModal1" id="btn_view" data-bs-toggle="modal" onClick="view_record_history(' + data.id + ')"><i class="fa fa-eye" style="margin-right:3px;"></i></a>';
                }
            },
        ],
        "paging": true,
        "pageLength": 10,
        "select": true,
        "order": [
            [1, 'asc'],
        ],
    });

    if (typeof tinyMCE !== 'undefined' && !tinyMCE.get('bmsi_mail_box')) {
        tinymce.init({
            selector: '#bmsi_mail_box',
            setup: function (editor) {
                editor.on('init', function () {
                });
            }
        });
    }

    function validate_create_template_form() {

        jQuery.validator.addMethod("noSpace", function (value, element) {
            return this.optional(element) || value.trim().indexOf(' ') === -1;
        }, "Template name cannot contain spaces.");

        var isValid = jQuery(".create_template").validate({
            rules: {
                template_name: {
                    required: true,
                    noSpace: true
                },
                subject: "required",
                mail_from: "required",
                admin_mail: "required",
                bmsi_mail_box_content: "required",
            },
            messages: {
                template_name: {
                    required: "Template name is required.",
                    noSpace: "Template name cannot contain spaces."
                },
                subject: {
                    required: "Subject is required."
                },
                mail_from: {
                    required: "Sender name is required."
                },
                admin_mail: {
                    required: "Sender email is required."
                },
                bmsi_mail_box_content: {
                    required: "Mail body is required."
                }
            },
        }).form();

        var bmsi_mail_box_content = tinyMCE.get('bmsi_mail_box').getContent();

        if (bmsi_mail_box_content == "<p>add some text</p>") {
            isValid = false;
            $(".bmsi_mail_box_error").text("Mail body is required.");
        } else {
            $("#bmsi_mail_box").text("");

        }

        return isValid;
    }

    jQuery(".btn-cnt").click(function (e) {
        e.preventDefault();
        if (!validate_create_template_form()) {
            return;
        }
        else {
            jQuery(".btn-txt").css("display", "none");
            jQuery(".spinn").addClass("add_custome_loader");
            jQuery(".btn-cnt").attr('disabled', 'disabled');

            var edit_id = jQuery("#template_id").val();
            var edit_permission = jQuery("#edit_permission").val();
            var template_name = jQuery("#template_name").val();
            var mail_sub = jQuery("#mail_sub").val();
            var mail_from = jQuery("#mail_from").val();
            var admin_mail = jQuery("#admin_mail").val();
            var email_body = tinyMCE.get('bmsi_mail_box').getContent();

            jQuery.ajax({
                "url": BMSI_object.ajax_url,
                "type": "POST",
                "dataType": "JSON",
                "data": {
                    "action": "BMSI_create_new_template",
                    "template_name": template_name,
                    "mail_sub": mail_sub,
                    "mail_from": mail_from,
                    "admin_mail": admin_mail,
                    "email_body": email_body,
                    "edit_id": edit_id,
                    "edit_permission": edit_permission,
                    "create_template": BMSI_object.nonce
                },
                success: function (response) {
                    jQuery.confirm({
                        title: response.title,
                        content: response.message,
                        theme: 'modern',
                        buttons: {
                            ok: {
                                text: 'OK',
                                btnClass: 'add-button',
                                action: function () {
                                    if (response.status == true) {
                                        window.location.href = BMSI_object.admin_url + "admin.php?page=templates";
                                    }
                                }
                            }
                        }
                    });
                    jQuery(".btn-txt").css("display", "block");
                    jQuery(".spinn").removeClass("add_custome_loader");
                    jQuery(".btn-cnt").removeAttr('disabled');


                }, error: function (jqXHR, textStatus, errorThrown) {
                    if (textStatus === 'timeout') {
                        jQuery.confirm({
                            title: "Alert!",
                            content: "The request timed out. Please try again",
                            theme: 'modern',
                            buttons: {
                                ok: {
                                    text: 'OK',
                                    btnClass: 'add-button',
                                    action: function () {
                                        return
                                    }
                                }
                            }
                        });
                    } else {
                        jQuery.confirm({
                            title: "Alert!",
                            content: "Something Went Wrong.",
                            theme: 'modern',
                            buttons: {
                                ok: {
                                    text: 'OK',
                                    btnClass: 'add-button',
                                    action: function () {
                                        return
                                    }
                                }
                            }
                        });
                    }
                    jQuery(".btn-txt").css("display", "block");
                    jQuery(".spinn").removeClass("add_custome_loader");
                    jQuery(".btn-cnt").removeAttr('disabled');

                },
            })
        }
    });

    // news letter copy btn

    jQuery("#news_button").click(function (e) {
        e.preventDefault();

        var copyText = document.getElementById("Shortcode").value;


        navigator.clipboard.writeText(copyText);

        jQuery.confirm({
            title: 'Well Done!',
            content: "Shortcode Copied Successfully",
            theme: 'modern',
            buttons: {
                ok: {
                    text: 'OK',
                    btnClass: 'add-button',
                    action: function () {
                        return;
                    }
                }
            }
        });


    });

    jQuery('#status_filter').on('change', function () {
        email_table.draw();
    });

    jQuery('#category_filter').on('change', function () {
        email_table.draw();
    });

    var email_table = jQuery('#get_all_email').DataTable({
        "searching": true,
        "filter": true,
        "processing": true,
        "serverSide": true,
        "bInfo": false,
        "ajax": {
            "url": BMSI_object.ajax_url,
            "type": "POST",
            "data": function (d) {
                d.action = "BMSI_display_email";
                d.start_date = jQuery("#start").val();
                d.end_date = jQuery("#end").val();
                d.email_nonce = BMSI_object.nonce;
                d.category = jQuery("#category_filter").val();
                d.status = jQuery("#status_filter").val();
            }
        },
        language: {
            searchPlaceholder: "Search By Email",
            sLengthMenu: "Show  _MENU_  Entries",
            search: "",
            paginate: {
                "first": "<i class='text-white fa-solid fa-backward'></i>",
                "last": "<i class='text-white fa-solid fa-forward'></i>",
                "next": "<i class='text-white fa-solid fa-caret-right'></i>",
                "previous": "<i class='text-white fa-solid fa-caret-left'></i>"
            }
        },
        "columns": [
            { "data": "id", sortable: true },
            { "data": "email", sortable: true },
            { "data": "parentcategory", sortable: true },
            { "data": "subcategory", sortable: true },
            { "data": "tag", sortable: true },
            {
                "data": "status",
                className: "dt-center email_status_th d-flex justify-content-center",
                sortable: true,
                render: function (data, type, row) {
                    if (data == "Active") {
                        return '<div class="email_status"> ' + data + ' </div>';
                    } else {
                        return '<div class="email_status_inactive"> ' + data + ' </div>';
                    }
                }
            },
            {
                data: null,
                className: "dt-center editor-edit",
                sortable: false,
                render: function (data, type, row) {
                    return '<div><a href="javascript:void(0);" data-bs-target="#exampleModal1" id="btn_view" data-bs-toggle="modal" onClick="view_news_letter(' + data.id + ')"><i class="fa fa-eye" style="margin-right:3px;"></i></a><a href="' + BMSI_object.admin_url + 'admin.php?page=newsletter&email_id=' + data.id + '&edit=true" id="btn_edit" ><i class="fa-solid fa-pen-to-square"></i></a><a href="javascript:void(0);" id="btn_delete" onClick="delete_news_letter_email(\'' + data.id + '\')"><i class="fas fa-trash-alt" style="margin-right:3px;"></i></a>';
                }
            }
        ],
        "paging": true,
        "pageLength": 10,
        "select": true,
        "order": [
            [1, 'asc']
        ]
    });

    // add new category

    function validate_add_category_form() {
        return jQuery(".new_letter_add_category").validate({
            rules: {
                categoryp: {
                    required: false
                },
                categorys: {
                    required: false
                }
            },
        }).form();
    }

    function validate_add_tag_form() {
        return jQuery(".new_letter_add_tag").validate({
            rules: {
                categoryp: {
                    required: false
                },
                categorys: {
                    required: false
                }
            },
        }).form();
    }

    jQuery(".btn-new-category").click(function (e) {
        e.preventDefault();

        if (!validate_add_category_form()) {
            return;
        } else {

            jQuery(".new_letter_add_category .btn-txt").css("display", "none");
            jQuery(".new_letter_add_category .spinn").addClass("add_custome_loader");
            jQuery(".btn-new-category").attr('disabled', 'disabled');


            var categoryp = jQuery("#categoryp").val();
            var categorys = jQuery("#categorys").val();
            var parentcategory = jQuery("#parentcategory").val();
            var category_id = jQuery("#edit_id").val();
            var edit = jQuery("#edit").val();

            jQuery.ajax({
                "url": BMSI_object.ajax_url,
                "type": "POST",
                "dataType": "JSON",
                "data": {
                    "action": "BMSI_add_new_category",
                    "categoryp": categoryp,
                    "categorys": categorys,
                    "parentcategory": parentcategory,
                    "category_id": category_id,
                    "edit": edit,
                    "news_letter_category_nonce": BMSI_object.nonce,
                },
                success: function (response) {
                    jQuery.confirm({
                        title: response.title,
                        content: response.message,
                        theme: 'modern',
                        buttons: {
                            ok: {
                                text: 'OK',
                                btnClass: 'add-button',
                                action: function () {
                                    if (response.status == true) {
                                        window.location.href = BMSI_object.admin_url + "admin.php?page=newsletter_category";
                                    }
                                }
                            }
                        }
                    });
                    jQuery(".new_letter_add_category .btn-txt").css("display", "block");
                    jQuery(".new_letter_add_category .spinn").removeClass("add_custome_loader");
                    jQuery(".btn-new-category").removeAttr('disabled');


                }, error: function (jqXHR, textStatus, errorThrown) {
                    if (textStatus === 'timeout') {
                        jQuery.confirm({
                            title: "Alert!",
                            content: "The request timed out. Please try again",
                            theme: 'modern',
                            buttons: {
                                ok: {
                                    text: 'OK',
                                    btnClass: 'add-button',
                                    action: function () {
                                        return

                                    }
                                }
                            }
                        });
                    } else {
                        jQuery.confirm({
                            title: "Alert!",
                            content: "Something Went Wrong.",
                            theme: 'modern',
                            buttons: {
                                ok: {
                                    text: 'OK',
                                    btnClass: 'add-button',
                                    action: function () {
                                        return
                                    }
                                }
                            }
                        });
                    }
                    jQuery(".btn-txt").css("display", "block");
                    jQuery(".spinn").removeClass("add_custome_loader");
                    jQuery(".btn-new-category").removeAttr('disabled');

                },
            });
        }
    });

    jQuery(".btn-new-tag").click(function (e) {
        e.preventDefault();

        if (!validate_add_tag_form()) {
            return;
        } else {

            jQuery(".new_letter_add_tag .btn-txt").css("display", "none");
            jQuery(".new_letter_add_tag .spinn").addClass("add_custome_loader");
            jQuery(".btn-new-tag").attr('disabled', 'disabled');


            var tagp = jQuery("#tagp").val();
            var tags = jQuery("#tags").val();
            var parenttag = jQuery("#parenttag").val();
            var tag_id = jQuery("#edit_id").val();
            var edit = jQuery("#edit").val();

            jQuery.ajax({
                "url": BMSI_object.ajax_url,
                "type": "POST",
                "dataType": "JSON",
                "data": {
                    "action": "BMSI_add_new_tag",
                    "tagp": tagp,
                    "tags": tags,
                    "parenttag": parenttag,
                    "tag_id": tag_id,
                    "edit": edit,
                    "news_letter_tag_nonce": BMSI_object.nonce,
                },
                success: function (response) {
                    jQuery.confirm({
                        title: response.title,
                        content: response.message,
                        theme: 'modern',
                        buttons: {
                            ok: {
                                text: 'OK',
                                btnClass: 'add-button',
                                action: function () {
                                    if (response.status == true) {
                                        window.location.href = BMSI_object.admin_url + "admin.php?page=newsletter_tags";
                                    }
                                }
                            }
                        }
                    });
                    jQuery(".new_letter_add_tag .btn-txt").css("display", "block");
                    jQuery(".new_letter_add_tag .spinn").removeClass("add_custome_loader");
                    jQuery(".btn-new-tag").removeAttr('disabled');


                }, error: function (jqXHR, textStatus, errorThrown) {
                    if (textStatus === 'timeout') {
                        jQuery.confirm({
                            title: "Alert!",
                            content: "The request timed out. Please try again",
                            theme: 'modern',
                            buttons: {
                                ok: {
                                    text: 'OK',
                                    btnClass: 'add-button',
                                    action: function () {
                                        return

                                    }
                                }
                            }
                        });
                    } else {
                        jQuernew_letter_add_tagy.confirm({
                            title: "Alert!",
                            content: "Something Went Wrong.",
                            theme: 'modern',
                            buttons: {
                                ok: {
                                    text: 'OK',
                                    btnClass: 'add-button',
                                    action: function () {
                                        return
                                    }
                                }
                            }
                        });
                    }
                    jQuery(".btn-txt").css("display", "block");
                    jQuery(".spinn").removeClass("add_custome_loader");
                    jQuery(".btn-new-tag").removeAttr('disabled');

                },
            });
        }
    });

    //get all news letters category
    var table = jQuery('#get_all_news_letters_category').DataTable({
        "searching": true,
        "filter": true,
        "processing": true,
        "serverSide": true,
        "bInfo": false,
        "ajax": {
            "url": BMSI_object.ajax_url,
            "type": "POST",
            "data": function (d) {
                d.action = "BMSI_display_newsletters_category";
                d.start_date = jQuery("#start").val();
                d.end_date = jQuery("#end").val();
                d.news_letter_category_nonce = BMSI_object.nonce;
            },
            "dataSrc": function (json) {
                var data = [];
                json.data.forEach(function (item) {
                    if (item.category_name != "uncategory") {
                        data.push({
                            "id": item.id,
                            "category_name": item.category_name,
                            "type": item.type
                        });
                        if (item.sub_categories) {
                            item.sub_categories.forEach(function (sub) {
                                data.push({
                                    "id": sub.id,
                                    "category_name": sub.category_name,
                                    "type": "sub"
                                });
                            });
                        }
                    }
                });
                return data;
            }
        },
        language: {
            searchPlaceholder: "Search By Category Name",
            sLengthMenu: "Show  _MENU_  Entries",
            search: "",
            paginate: {
                "first": "<i class='fa-solid fa-backward'></i>",
                "last": "<i class='fa-solid fa-forward'></i>",
                "next": "<i class='fa-solid fa-caret-right'></i>",
                "previous": "<i class='fa-solid fa-caret-left'></i>"
            },
        },
        "columns": [
            {
                "data": "category_name",
                "sortable": true,
                "render": function (data, type, row) {
                    if (row.type === 'sub') {
                        return '— ' + data;
                    }
                    return data;
                }
            },
            {
                data: null,
                className: "dt-center editor-edit",
                sortable: false,
                render: function (data, type, row) {
                    if (row.type === 'sub') {
                        return '<div><a href="' + BMSI_object.admin_url + 'admin.php?page=newsletter_category&sub_category_id=' + data.id + '&edit=true" id="btn_edit" ><i class="fa-solid fa-pen-to-square"></i></a><a href="javascript:void(0);" id="btn_delete" onClick="delete_sub_category(\'' + data.id + '\')"><i class="fas fa-trash-alt" style="margin-right:3px;"></i></a></div>';
                    } else {
                        return '<div><a href="' + BMSI_object.admin_url + 'admin.php?page=newsletter_category&category_id=' + data.id + '&edit=true" id="btn_edit" ><i class="fa-solid fa-pen-to-square"></i></a><a href="javascript:void(0);" id="btn_delete" onClick="delete_category(\'' + data.id + '\')"><i class="fas fa-trash-alt" style="margin-right:3px;"></i></a></div>';
                    }
                }
            },
        ],
        "paging": true,
        "pageLength": 10,
        "select": true,
        "order": [
            [1, 'asc'],
        ],
    });

    var table = jQuery('#get_all_news_letters_tags').DataTable({
        "searching": true,
        "filter": true,
        "processing": true,
        "serverSide": true,
        "bInfo": false,
        "ajax": {
            "url": BMSI_object.ajax_url,
            "type": "POST",
            "data": function (d) {
                d.action = "BMSI_display_newsletters_tag";
                d.start_date = jQuery("#start").val();
                d.end_date = jQuery("#end").val();
                d.news_letter_tag_nonce = BMSI_object.nonce;
            },
            "dataSrc": function (json) {
                var data = [];
                json.data.forEach(function (item) {
                    if (item.tags_name != "uncategory") {
                        data.push({
                            "id": item.id,
                            "tags_name": item.tags_name,
                            "type": item.type
                        });
                    }
                });
                return data;
            }
        },
        language: {
            searchPlaceholder: "Search By Category Name",
            sLengthMenu: "Show  _MENU_  Entries",
            search: "",
            paginate: {
                "first": "<i class='fa-solid fa-backward'></i>",
                "last": "<i class='fa-solid fa-forward'></i>",
                "next": "<i class='fa-solid fa-caret-right'></i>",
                "previous": "<i class='fa-solid fa-caret-left'></i>"
            },
        },
        "columns": [
            {
                "data": "tags_name",
                "sortable": true,
                "render": function (data, row) {
                    return data;
                }
            },
            {
                data: null,
                className: "dt-center editor-edit",
                sortable: false,
                render: function (data, type, row) {
                    return '<div><a href="' + BMSI_object.admin_url + 'admin.php?page=newsletter_tags&tag_id=' + data.id + '&edit=true" id="btn_edit" ><i class="fa-solid fa-pen-to-square"></i></a><a href="javascript:void(0);" id="btn_delete" onClick="delete_tags(\'' + data.id + '\')"><i class="fas fa-trash-alt" style="margin-right:3px;"></i></a></div>';
                }
            },
        ],
        "paging": true,
        "pageLength": 10,
        "select": true,
        "order": [
            [1, 'asc'],
        ],
    });

    //add news letter user form admin

    function validate_add_user_category_form() {
        jQuery.validator.addMethod("noSpace", function (value, element) {
            return this.optional(element) || !/\s/.test(value);
        }, "You can't use spaces.");

        return jQuery(".new_letter_add_email_category").validate({
            rules: {
                news_letter_email: {
                    required: true,
                    noSpace: true
                },
                parentcategory: {
                    required: true,
                    noSpace: false
                },
                status: {
                    required: true,
                    noSpace: false
                },
            },
            messages: {
                news_letter_email: {
                    required: "Email is required.",
                    noSpace: "Spaces are not allowed in the email address."
                },
                parentcategory: {
                    required: "Parent Category is required.",
                },
                status: {
                    required: "Status is required.",
                },
            },
        }).form();
    }

    jQuery(".btn-news-letter-user").click(function (e) {
        e.preventDefault();

        if (!validate_add_user_category_form()) {
            return;
        } else {

            jQuery(".new_letter_add_email_category .btn-new").css("display", "none");
            jQuery(".new_letter_add_email_category .spinn").addClass("add_custome_loader");
            jQuery(".btn-news-letter-user").attr('disabled', 'disabled');


            var email = jQuery("#news_letter_email").val();
            var tags = jQuery("#tagsSelect").val();
            var fname = jQuery("#fname").val();
            var lname = jQuery("#lname").val();
            var job_title = jQuery("#job_title").val();
            var company = jQuery("#company").val();
            var birthdate = jQuery("#birthdate").val();
            var anniversary = jQuery("#anniversary").val();
            var status = jQuery("#status").val();

            var parentcategory = jQuery('#parentcategory').find('option:selected').filter(function () {
                return jQuery(this).hasClass('level-0');
            }).val();

            var subcategory = jQuery('#parentcategory').find('option:selected').filter(function () {
                return jQuery(this).hasClass('level-1');
            }).val();

            console.log(parentcategory);
            console.log(subcategory);

            jQuery.ajax({
                "url": BMSI_object.ajax_url,
                "type": "POST",
                "dataType": "JSON",
                "data": {
                    "action": "BMSI_add_news_letter_user_category",
                    "email": email,
                    "category": parentcategory,
                    "subcategory": subcategory,
                    "tags": tags,
                    "fname": fname,
                    "lname": lname,
                    "job_title": job_title,
                    "company": company,
                    "birthdate": birthdate,
                    "anniversary": anniversary,
                    "status": status,
                    "news_letter_category_nonce": BMSI_object.nonce,
                },
                success: function (response) {
                    jQuery.confirm({
                        title: response.title,
                        content: response.message,
                        theme: 'modern',
                        buttons: {
                            ok: {
                                text: 'OK',
                                btnClass: 'add-button',
                                action: function () {
                                    if (response.status == true) {
                                        window.location.href = BMSI_object.admin_url + "admin.php?page=newsletter";
                                    }
                                }
                            }
                        }
                    });
                    jQuery(".btn-new").css("display", "block");
                    jQuery(".spinn").removeClass("add_custome_loader");
                    jQuery(".btn-news-letter-user").removeAttr('disabled');

                }, error: function (jqXHR, textStatus, errorThrown) {
                    if (textStatus === 'timeout') {
                        jQuery.confirm({
                            title: "Alert!",
                            content: "The request timed out. Please try again",
                            theme: 'modern',
                            buttons: {
                                ok: {
                                    text: 'OK',
                                    btnClass: 'add-button',
                                    action: function () {
                                        return
                                    }
                                }
                            }
                        });
                    } else {
                        jQuery.confirm({
                            title: "Alert!",
                            content: "Something Went Wrong.",
                            theme: 'modern',
                            buttons: {
                                ok: {
                                    text: 'OK',
                                    btnClass: 'add-button',
                                    action: function () {
                                        return
                                    }
                                }
                            }
                        });
                    }
                    jQuery(".btn-txt").css("display", "block");
                    jQuery(".spinn").removeClass("add_custome_loader");
                    jQuery(".btn-news-letter-user").removeAttr('disabled');

                },
            });
        }
    });

    function validate_activation_key_form() {

        return jQuery(".BMSI_pro_activation_form").validate({
            rules: {
                activation_key: {
                    required: true,
                },
            },
            messages: {
                activation_key: {
                    required: "Activaion Key is required.",
                },
            },
        }).form();
    }

    jQuery(".btn-submit-key").click(function (e) {
        e.preventDefault();

        if (!validate_activation_key_form()) {
            return;
        } else {

            jQuery("#tab5 .btn-txt").css("display", "none");
            jQuery("#tab5 .spinn").addClass("add_custome_loader");
            jQuery(".btn-submit-key").attr('disabled', 'disabled');

            var activation_key = jQuery("#activation_key").val();

            jQuery.ajax({
                "url": BMSI_object.ajax_url,
                "type": "POST",
                "dataType": "JSON",
                "data": {
                    "action": "save_activation_key",
                    "activation_key": activation_key,
                    "BMSI_PRO_nonce": BMSI_object.nonce,
                },
                success: function (response) {
                    location.reload();
                    jQuery("#tab5 .btn-txt").css("display", "block");
                    jQuery("#tab5 .spinn").removeClass("add_custome_loader");
                    jQuery(".btn-submit-key").removeAttr('disabled');

                }
            });
        }
    });

    jQuery(".btn-news-letter-email-edit").click(function (e) {
        e.preventDefault();

        if (!validate_add_user_category_form()) {
            return;
        } else {

            jQuery(".new_letter_add_email_category .btn-new").css("display", "none");
            jQuery(".new_letter_add_email_category .spinn").addClass("add_custome_loader");
            jQuery(".btn-news-letter-email-edit").attr('disabled', 'disabled');

            var tags = jQuery("#tagsSelect").val();;
            var fname = jQuery("#fname").val();
            var lname = jQuery("#lname").val();
            var job_title = jQuery("#job_title").val();
            var company = jQuery("#company").val();
            var birthdate = jQuery("#birthdate").val();
            var anniversary = jQuery("#anniversary").val();
            var email = jQuery("#news_letter_email").val();
            var email_id = jQuery("#email_id").val();
            var status = jQuery("#status").val();

            var parentcategory = jQuery('#parentcategory').find('option:selected').filter(function () {
                return jQuery(this).hasClass('level-0');
            }).val();

            var subcategory = jQuery('#parentcategory').find('option:selected').filter(function () {
                return jQuery(this).hasClass('level-1');
            }).val();

            jQuery.ajax({
                url: BMSI_object.ajax_url,
                type: "POST",
                dataType: "JSON",
                data: {
                    action: "BMSI_edit_news_letter_user_category",
                    email: email,
                    parentcategory: parentcategory,
                    subcategory: subcategory,
                    id: email_id,
                    tags: tags,
                    fname: fname,
                    lname: lname,
                    job_title: job_title,
                    company: company,
                    birthdate: birthdate,
                    anniversary: anniversary,
                    status: status,
                    news_letter_category_nonce: BMSI_object.nonce,
                },
                success: function (response) {
                    jQuery.confirm({
                        title: response.title,
                        content: response.message,
                        theme: 'modern',
                        buttons: {
                            ok: {
                                text: 'OK',
                                btnClass: 'add-button',
                                action: function () {
                                    if (response.status == true) {
                                        window.location.href = BMSI_object.admin_url + "admin.php?page=newsletter";
                                    }
                                }
                            }
                        }
                    });
                    jQuery(".btn-new").css("display", "block");
                    jQuery(".spinn").removeClass("add_custome_loader");
                    jQuery(".btn-news-letter-email-edit").removeAttr('disabled');
                },
            });

        }
    });

    jQuery(".btn-import-email").click(function (e) {
        e.preventDefault();

        var site_url = jQuery("#site_url").val();

        // jQuery.confirm({
        //     title: 'Import File',
        //     content: '' +
        //         '<form id="import-form">' +
        //         '<div class="form-group">' +
        //         '<label class="custom-file-label" for="import-file">Choose file</label>' +
        //         '<input type="file" id="import-file" accept=".csv, .xlsx, .json" class="custom-file-input" required />' +
        //         '<p style="color:red;" class="mt-2 mb-0">*Email , Parent Category and Status is requied filed in file.</p>' +
        //         '<p class="mt-2 mb-0">Demo File :- <a href=" ' + site_url + 'assets/demo/demo.json" download>Json</a><a class="mx-2" href="' + site_url + 'assets/demo/demo.xlsx" download> xlsx</a><a href="' + site_url + 'assets/demo/demo.csv" download> csv</a></p>' +
        //         '</div>' +
        //         '</form>',
        //     theme: 'modern',
        //     buttons: {
        //         Import: {
        //             btnClass: 'add-button import-email',
        //             action: function ($) {
        //                 let fileInput = this.$content.find('#import-file')[0];
        //                 if (fileInput.files.length === 0) {
        //                     jQuery.alert({
        //                         title: 'No File Selected',
        //                         content: 'Please select a file to import.',
        //                         theme: 'modern',
        //                     });
        //                     return false;
        //                 }

        //                 let file = fileInput.files[0];
        //                 let allowedExtensions = /(\.csv|\.xlsx|\.json)$/i;
        //                 if (!allowedExtensions.exec(file.name)) {
        //                     jQuery.alert({
        //                         title: 'Invalid File',
        //                         content: 'Please upload a valid file with .csv, .xlsx, or .json extension.',
        //                         theme: 'modern',
        //                     });
        //                     return false;
        //                 }

        //                 let formData = new FormData();
        //                 formData.append('file', file);
        //                 formData.append('action', 'BMSI_Import_newsletter_email');
        //                 formData.append('import_file_nonce', BMSI_object.nonce);


        //                 let importButton = jQuery(".import-email");
        //                 importButton.prop('disabled', true).html('<span class="loader"></span>');

        //                 jQuery.ajax({
        //                     url: BMSI_object.ajax_url,
        //                     type: "POST",
        //                     data: formData,
        //                     processData: false,
        //                     contentType: false,
        //                     success: function (response) {

        //                         jQuery.confirm({
        //                             title: 'Imported!',
        //                             content: response.message,
        //                             theme: 'modern',
        //                             buttons: {
        //                                 ok: {
        //                                     text: 'OK',
        //                                     btnClass: 'add-button',
        //                                     action: function () {
        //                                         if (response.status == true) {
        //                                             location.reload();
        //                                         }
        //                                     }
        //                                 }
        //                             }
        //                         });

        //                         importButton.prop('disabled', false).html('Import');
        //                     },
        //                     error: function (jqXHR, textStatus, errorThrown) {

        //                         jQuery.alert({
        //                             title: 'Error!',
        //                             content: 'There was an error processing the file. Please try again.',
        //                             theme: 'modern',
        //                         });

        //                         importButton.prop('disabled', false).html('Import');
        //                     }
        //                 });

        //                 return false;
        //             }
        //         },
        //         Cancel: {
        //             btnClass: 'add-button',
        //         }
        //     },
        // });
        
        var content = jQuery('#import-form');
        var defaultFileName = "Choose file";
        content.find('.custom-file-label').html(defaultFileName);

        content.find('#import-file').on('change', function () {
            var fileName = $(this).val().split('\\').pop();
            if (fileName) {
                $(this).siblings('.custom-file-label').addClass('selected').html(fileName);
            } else {
                $(this).siblings('.custom-file-label').removeClass('selected').html(defaultFileName);
            }
        });
    });

    jQuery('#import-file').change(function() {
       if (jQuery(this).val() != '') {    
            let fileInput = document.getElementById('import-file');
            let file = fileInput.files[0];
    
            let allowedExtensions = /(\.csv|\.xlsx|\.json)$/i;
            if (!allowedExtensions.exec(file.name)) {
                jQuery.alert({
                    title: 'Invalid File',
                    content: 'Please upload a valid file with .csv, .xlsx, or .json extension.',
                    theme: 'modern',
                });
                return false;
            }

            jQuery('#import-form').append(
                '<div id="LoaderForImportModal" class="text-center m-5">'+
                    '<div class="spinner-border m-5" style="width: 3rem; height: 3rem;" role="status">'+
                        '<span class="sr-only">Loading...</span>'+
                    '</div>'+
                '</div>'
            );
    
            let formData = new FormData();
            formData.append('file', file);
            formData.append('action', 'BMSI_Import_newsletter_email_columnlist');
            formData.append('import_file_nonce', BMSI_object.nonce);
    
            jQuery.ajax({
                url: BMSI_object.ajax_url,
                type: "POST",
                data: formData,
                processData: false,
                contentType: false,
                success: function(response) {
                    jQuery('#LoaderForImportModal').remove();

                    jQuery('#fieldsOfImportForm').removeClass('d-none');
                    
                    const fields = response.data;
                    const selects = jQuery('#fieldsOfImportForm select');
                    selects.each(function() {
                        const select = jQuery(this);
                        select.empty(); // Clear previous options
    
                        // Append the "Select an option" first
                        select.append(jQuery('<option>', {
                            value: "",
                            text: "Select an option"
                        }));
    
                        // Append new options from the response data
                        fields.forEach(field => {
                            select.append(jQuery('<option>', {
                                value: field,
                                text: field.charAt(0).toUpperCase() + field.slice(1)
                            }));
                        });
                    });
                    
                    function updateSelectOptions() {
                        // Enable all options in all select elements first
                        selects.find('option').prop('disabled', false);
    
                        // Disable the selected option in all other select elements
                        selects.each(function() {
                            const selectedValue = jQuery(this).val();
                            if (selectedValue) {
                                selects.not(this).find(`option[value="${selectedValue}"]`).prop('disabled', true);
                            }
                        });
    
                        // Always enable the "Select an option"
                        selects.find('option[value=""]').prop('disabled', false);
                    }
    
                    // Add change event listener to each select
                    selects.change(function() {
                        updateSelectOptions();
                    });
    
                    // Trigger change event to handle initial state
                    updateSelectOptions();
                },
                error: function(jqXHR, textStatus, errorThrown) {
                    jQuery.alert({
                        title: 'Error!',
                        content: 'There was an error processing the file. Please try again.',
                        theme: 'modern',
                    });
    
                    jQuery('#ImportButton').prop('disabled', false).html('Import');
                }
            });
        } else {
            jQuery.alert({
                title: 'No File Selected',
                content: 'Please select a file to import.',
                theme: 'modern',
            });
            return false;
        }
    });
    
    jQuery('#CloseButton').click(function(){
        jQuery('#import-file').val();
        jQuery('#fieldsOfImportForm').addClass('d-none');
    });

    jQuery('#CloseButtonFooter').click(function(){
        jQuery('#import-file').val();
        jQuery('#fieldsOfImportForm').addClass('d-none');
    });

    jQuery('#ImportButton').click(function() {
        var content = jQuery('#import-form');
        let fileInput = content.find('#import-file')[0];
        let fname = content.find('#first_name').val().trim();
        let lname = content.find('#last_name').val().trim();
        let email = content.find('#email').val().trim();
    
        // Check if the required fields are empty
        if (!fname || !lname || !email) {
            jQuery.alert({
                title: 'Missing Fields',
                content: 'First Name, Last Name, and Email are required fields.',
                theme: 'modern',
            });
            return false;
        }
    
        // Check if a file is selected
        if (fileInput.files.length === 0) {
            jQuery.alert({
                title: 'No File Selected',
                content: 'Please select a file to import.',
                theme: 'modern',
            });
            return false;
        }
    
        let file = fileInput.files[0];
        let allowedExtensions = /(\.csv|\.xlsx|\.json)$/i;
        if (!allowedExtensions.exec(file.name)) {
            jQuery.alert({
                title: 'Invalid File',
                content: 'Please upload a valid file with .csv, .xlsx, or .json extension.',
                theme: 'modern',
            });
            return false;
        }
        // jQuery('#import-form').append(
        //     '<div id="LoaderForImportModal" class="text-center m-5">'+
        //         '<div class="spinner-border m-5" style="width: 3rem; height: 3rem;" role="status">'+
        //             '<span class="sr-only">Loading...</span>'+
        //         '</div>'+
        //     '</div>'
        // );

        jQuery(".btn-txt").css("display", "none");
        jQuery(".spinn").addClass("add_custome_loader");
        jQuery(".btn-cnt").attr('disabled', 'disabled');
        let formData = new FormData();
        formData.append('file', file);
        formData.append('action', 'BMSI_Import_newsletter_email');
        formData.append('import_file_nonce', BMSI_object.nonce);
    
        // Append all select field values to the FormData
        content.find('select').each(function() {
            formData.append(jQuery(this).attr('name'), jQuery(this).val());
        });
    
        let importButton = jQuery(".import-email");
        importButton.prop('disabled', true).html('<span class="loader"></span>');
    
        jQuery.ajax({
            url: BMSI_object.ajax_url,
            type: "POST",
            data: formData,
            processData: false,
            contentType: false,
            success: function(response) {

                jQuery(".btn-txt").css("display", "block");
                jQuery(".spinn").removeClass("add_custome_loader");
                jQuery(".btn-cnt").removeAttr('disabled');
                jQuery.confirm({
                    title: 'Imported!',
                    content: response.message,
                    theme: 'modern',
                    buttons: {
                        ok: {
                            text: 'OK',
                            btnClass: 'add-button',
                            action: function() {
                                if (response.status == true) {
                                    location.reload();
                                }
                            }
                        }
                    }
                });
    
                importButton.prop('disabled', false).html('Import');
            },
            error: function(jqXHR, textStatus, errorThrown) {
                jQuery.alert({
                    title: 'Error!',
                    content: 'There was an error processing the file. Please try again.',
                    theme: 'modern',
                });
    
                importButton.prop('disabled', false).html('Import');
            }
        });
    });
    

    jQuery(".btn-import-cateogry").click(function (e) {
        e.preventDefault();

        var site_url = jQuery("#site_url").val();

        jQuery.confirm({
            title: 'Import File',
            content: '' +
                '<form id="import-form">' +
                '<div class="form-group">' +
                '<label class="custom-file-label" for="import-file">Choose file</label>' +
                '<input type="file" id="import-file" accept=".csv, .xlsx, .json" class="custom-file-input" required />' +
                '<p style="color:red;" class="mt-2 mb-0">*Parent Category is required field in file.</p>' +
                '<p class="mt-2 mb-0">Demo File :- <a href="' + site_url + 'assets/demo/category_demo.json" download>Json</a><a class="mx-2" href="' + site_url + 'assets/demo/category_demo.xlsx" download> xlsx</a><a href="' + site_url + 'assets/demo/category_demo.csv" download> csv</a></p>' +
                '</div>' +
                '</form>',
            theme: 'modern',
            buttons: {
                Import: {
                    btnClass: 'add-button import-category',
                    action: function ($) {
                        let fileInput = this.$content.find('#import-file')[0];
                        if (fileInput.files.length === 0) {
                            jQuery.alert({
                                title: 'No File Selected',
                                content: 'Please select a file to import.',
                                theme: 'modern',
                            });
                            return false;
                        }

                        let file = fileInput.files[0];
                        let allowedExtensions = /(\.csv|\.xlsx|\.json)$/i;
                        if (!allowedExtensions.exec(file.name)) {
                            jQuery.alert({
                                title: 'Invalid File',
                                content: 'Please upload a valid file with .csv, .xlsx, or .json extension.',
                                theme: 'modern',
                            });
                            return false;
                        }

                        let formData = new FormData();
                        formData.append('file', file);
                        formData.append('action', 'BMSI_Import_newsletter_category');
                        formData.append('import_file_nonce', BMSI_object.nonce);

                        let importButton = jQuery(".import-category");
                        importButton.prop('disabled', true).html('<span class="loader"></span>');

                        jQuery.ajax({
                            url: BMSI_object.ajax_url,
                            type: "POST",
                            data: formData,
                            processData: false,
                            contentType: false,
                            success: function (response) {

                                jQuery.confirm({
                                    title: 'Imported!',
                                    content: response.message,
                                    theme: 'modern',
                                    buttons: {
                                        ok: {
                                            text: 'OK',
                                            btnClass: 'add-button',
                                            action: function () {
                                                if (response.status == true) {
                                                    location.reload();
                                                }
                                            }
                                        }
                                    }
                                });

                                importButton.prop('disabled', false).html('Import');
                            },
                            error: function (jqXHR, textStatus, errorThrown) {

                                jQuery.alert({
                                    title: 'Error!',
                                    content: 'There was an error processing the file. Please try again.',
                                    theme: 'modern',
                                });

                                importButton.prop('disabled', false).html('Import');
                            }
                        });

                        return false;
                    }
                },
                Cancel: {
                    btnClass: 'add-button',
                }
            },
            onContentReady: function () {
                var defaultFileName = "Choose file";
                this.$content.find('.custom-file-label').html(defaultFileName);

                this.$content.find('#import-file').on('change', function () {
                    var fileName = $(this).val().split('\\').pop();
                    if (fileName) {
                        $(this).siblings('.custom-file-label').addClass('selected').html(fileName);
                    } else {
                        $(this).siblings('.custom-file-label').removeClass('selected').html(defaultFileName);
                    }
                });
            }
        });
    });


})

function view_news_letter(Id) {
    jQuery.ajax({
        "url": BMSI_object.ajax_url,
        "type": "POST",
        "data": {
            "action": "BMSI_news_letter_record",
            "id": Id,
            "view_nonce": BMSI_object.nonce,
        },
        "success": function (response) {
            jQuery(".modal-body .id .news_letter_id").text(response['id']);
            jQuery(".modal-body .email .news_letter_email").text(response['email']);
            jQuery(".modal-body .category .news_letter_category").text(response['category']);
            jQuery(".modal-body .category .news_letter_subcategory").text(response['subcategory']);
            jQuery(".modal-body .CreatD .news_letter_CreatD").text(response['createdate']);
            jQuery(".modal-body .status .news_letter_status").text((response['status'] == "1") ? "active" : "Inactive");
        },
    });
}


function delete_template(id) {

    jQuery.confirm({
        title: '',
        content: 'Are you sure you want to delete?',
        theme: 'modern',
        buttons: {
            Yes: {
                btnClass: 'add-button',
                action: function () {
                    jQuery.ajax({
                        "url": BMSI_object.ajax_url,
                        "type": "POST",
                        "dataType": "JSON",
                        "data": {
                            "action": "BMSI_delete_template",
                            "template_id": id,
                            "delete_template_nonce": BMSI_object.nonce,
                        },
                        success: function (response) {
                            jQuery.confirm({
                                title: 'Deleted!',
                                content: response.message,
                                theme: 'modern',
                                buttons: {
                                    ok: {
                                        text: 'OK',
                                        btnClass: 'add-button',
                                        action: function () {
                                            if (response.status == true) {
                                                location.reload();
                                            }
                                        }
                                    }
                                }
                            });

                        },

                    })
                }
            },
            No: {
                btnClass: 'add-button',
            }
        }
    });



}

function view_record_history(id) {
    jQuery.ajax({
        url: BMSI_object.ajax_url,
        type: "POST",
        data: {
            action: "BMSI_view_record_history_pro",
            id: id,
            pro_history_nonce: BMSI_object.nonce,
        },
        success: function (response) {
            if (typeof tinyMCE !== 'undefined' && tinyMCE.get('bmsi_mail_box')) {
                tinyMCE.get('bmsi_mail_box').setContent(response.body);
            }
        }
    });
}

function delete_category(id) {
    fetchCategoriesAndSubcategories(id).done(function (response) {
        if (response.success && Array.isArray(response.data.data)) {
            var categories = response.data.data;

            var filteredCategories = categories.filter(function (category) {
                return category.id !== '1' && category.id !== id;
            });

            var categoryOptions = filteredCategories.map(function (category) {
                // Check if the category has subcategories
                var hasSubcategories = category.subcategories.length > 0;

                // Generate subcategory options
                var subCategoryOptions = category.subcategories.filter(function (subCategory) {
                    return subCategory.id !== id;
                }).map(function (subCategory) {
                    return `<option class="${subCategory.level}" value="${subCategory.id}">- ${subCategory.sub_category_name}</option>`;
                }).join('');

                // Include the category even if it doesn't have subcategories
                if (hasSubcategories) {
                    return `<option class="${category.level}" value="${category.id}">${category.category_name}</option>
                                ${subCategoryOptions}`;
                } else {
                    return `<option class="${category.level}" value="${category.id}">${category.category_name}</option>`;
                }
            }).join('');

            var content = 'Are you sure you want to delete?<br><br><div style="text-align: left;">' +
                '<input type="radio" name="deleteOption" value="option1" id="option1" checked>' +
                '<label for="option1">Delete all emails</label><br>' +
                '<input type="radio" name="deleteOption" value="option2" id="option2">' +
                '<label for="option2">Transfer all email to uncategory category.</label><br>';

            if (categoryOptions !== '') {
                content += '<input type="radio" name="deleteOption" value="option3" id="option3">' +
                    '<label for="option3">Transfer all email to specified category.</label><br>' +
                    '<div id="additionalOptions" class="d-flex flex-row gap-2 mt-2"></div></div>';
            } else {
                content += '</div>';
            }

            jQuery.confirm({
                title: '',
                content: content,
                theme: 'modern',
                onContentReady: function () {
                    var jc = this;

                    this.$content.find('input[name="deleteOption"]').on('change', function () {
                        var selectedOption = jQuery(this).val();
                        var additionalOptions = jc.$content.find('#additionalOptions');

                        if (selectedOption === 'option3' && categoryOptions !== '') {
                            additionalOptions.html(
                                `<div class="d-flex flex-column w-100 gap-1">Select Category <select class="w-100 m-0 selectcategory" id="selectBox1">
                                    ${categoryOptions}
                                </select></div>`
                            );
                        } else {
                            additionalOptions.html('');
                        }
                    });

                    jQuery('input[name="deleteOption"]:checked').trigger('change');
                },
                buttons: {
                    Yes: {
                        btnClass: 'add-button',
                        action: function () {
                            var selectedOption = jQuery('input[name="deleteOption"]:checked').val();
                            if (!selectedOption) {
                                jQuery.alert('Please select an option.');
                                return false;
                            }

                            var parentselectedCategory = null;
                            var subselectedCategory = null;
                            if (selectedOption === 'option3') {
                                parentselectedCategory = jQuery('#selectBox1').find('option:selected').filter(function () {
                                    return jQuery(this).hasClass('level-0');
                                }).val();

                                subselectedCategory = jQuery('#selectBox1').find('option:selected').filter(function () {
                                    return jQuery(this).hasClass('level-1');
                                }).val();
                            }

                            jQuery.ajax({
                                url: BMSI_object.ajax_url,
                                type: "POST",
                                dataType: "JSON",
                                data: {
                                    action: "BMSI_delete_category",
                                    id: id,
                                    delete_option: selectedOption,
                                    parentselectedCategory: parentselectedCategory,
                                    subselectedCategory: subselectedCategory,
                                    news_letter_category_nonce: BMSI_object.nonce,
                                },
                                success: function (response) {
                                    jQuery.confirm({
                                        title: 'Deleted!',
                                        content: response.message,
                                        theme: 'modern',
                                        buttons: {
                                            ok: {
                                                text: 'OK',
                                                btnClass: 'add-button',
                                                action: function () {
                                                    if (response.status == true) {
                                                        location.reload();
                                                    }
                                                }
                                            }
                                        }
                                    });
                                },
                            });
                        }
                    },
                    No: {
                        btnClass: 'add-button',
                    }
                },
            });
        }
    });
}

function delete_tags(id) {
    fetchTags(id).done(function (response) {
        if (response.success && Array.isArray(response.data.data)) {
            var tags = response.data.data;

            var filteredtags = tags.filter(function (category) {
                return category.id !== '1' && category.id !== id;
            });

            var categoryOptions = filteredtags.map(function (category) {
                // Check if the category has subtags
                var hasSubtags = category.subtags.length > 0;

                // Generate subcategory options
                var subCategoryOptions = category.subtags.filter(function (subCategory) {
                    return subCategory.id !== id;
                }).map(function (subCategory) {
                    return `<option class="${subCategory.level}" value="${subCategory.id}">- ${subCategory.sub_category_name}</option>`;
                }).join('');

                // Include the category even if it doesn't have subtags
                if (hasSubtags) {
                    return `<option class="${category.level}" value="${category.id}">${category.category_name}</option>
                                ${subCategoryOptions}`;
                } else {
                    return `<option class="${category.level}" value="${category.id}">${category.category_name}</option>`;
                }
            }).join('');

            jQuery.confirm({
                title: '',
                theme: 'modern',
                buttons: {
                    Yes: {
                        btnClass: 'add-button',
                        action: function () {
                            var parentselectedCategory = null;
                            var subselectedCategory = null;

                            jQuery.ajax({
                                url: BMSI_object.ajax_url,
                                type: "POST",
                                dataType: "JSON",
                                data: {
                                    action: "BMSI_delete_tag",
                                    id: id,
                                    parentselectedCategory: parentselectedCategory,
                                    subselectedCategory: subselectedCategory,
                                    news_letter_tag_nonce: BMSI_object.nonce,
                                },
                                success: function (response) {
                                    jQuery.confirm({
                                        title: 'Deleted!',
                                        content: response.message,
                                        theme: 'modern',
                                        buttons: {
                                            ok: {
                                                text: 'OK',
                                                btnClass: 'add-button',
                                                action: function () {
                                                    if (response.status == true) {
                                                        location.reload();
                                                    }
                                                }
                                            }
                                        }
                                    });
                                },
                            });
                        }
                    },
                    No: {
                        btnClass: 'add-button',
                    }
                },
            });
        }
    });
}

function fetchCategoriesAndSubcategories(id) {
    return jQuery.ajax({
        url: BMSI_object.ajax_url,
        type: 'POST',
        dataType: 'JSON',
        data: {
            action: 'BMSI_fetch_categories_and_subcategories',
            id: id,
            news_letter_category_nonce: BMSI_object.nonce,
        }
    });
}

function fetchTags(id) {
    return jQuery.ajax({
        url: BMSI_object.ajax_url,
        type: 'POST',
        dataType: 'JSON',
        data: {
            action: 'BMSI_fetch_tags',
            id: id,
            news_letter_tag_nonce: BMSI_object.nonce,
        }
    });
}




function delete_news_letter_email(id) {
    jQuery.confirm({
        title: '',
        content: 'Are you sure you want to delete?',
        theme: 'modern',
        buttons: {
            Yes: {
                btnClass: 'add-button',
                action: function () {
                    jQuery.ajax({
                        "url": BMSI_object.ajax_url,
                        "type": "POST",
                        "dataType": "JSON",
                        "data": {
                            "action": "BMSI_delete_news_letter_email",
                            "id": id,
                            "news_letter_email_nonce": BMSI_object.nonce,
                        },
                        success: function (response) {
                            jQuery.confirm({
                                title: 'Deleted!',
                                content: response.message,
                                theme: 'modern',
                                buttons: {
                                    ok: {
                                        text: 'OK',
                                        btnClass: 'add-button',
                                        action: function () {
                                            if (response.status == true) {
                                                location.reload();
                                            }
                                        }
                                    }
                                }
                            });

                        },
                    })

                }
            },
            No: {
                btnClass: 'add-button',
            }
        },
    })

}

function delete_sub_category(id) {
    fetchCategoriesAndSubcategories(id).done(function (response) {
        if (response.success && Array.isArray(response.data.data)) {
            var categories = response.data.data;

            var filteredCategories = categories.filter(function (category) {
                return category.id !== '1';
            });

            var categoryOptions = filteredCategories.map(function (category) {
                var subCategoryOptions = category.subcategories.filter(function (subCategory) {
                    return subCategory.id !== id;
                }).map(function (subCategory) {
                    return `<option class="${subCategory.level}" value="${subCategory.id}">&nbsp;&nbsp;&nbsp;- ${subCategory.sub_category_name}</option>`;
                }).join('');

                if (subCategoryOptions) {
                    return `<option class="${category.level}" value="${category.id}">${category.category_name}</option>
                                ${subCategoryOptions}
                            `;
                } else {
                    return `<option class="${category.level}" value="${category.id}">${category.category_name}</option>`;
                }
            }).join('');

            var content = 'Are you sure you want to delete?<br><br><div style="text-align: left;">' +
                '<input type="radio" name="deleteOption" value="option1" id="option1" checked>' +
                '<label for="option1">Delete all emails</label><br>' +
                '<input type="radio" name="deleteOption" value="option2" id="option2">' +
                '<label for="option2">Transfer all email to uncategory category.</label><br>';

            if (categoryOptions !== '') {
                content += '<input type="radio" name="deleteOption" value="option3" id="option3">' +
                    '<label for="option3">Transfer all email to specified category.</label><br>' +
                    '<div id="additionalOptions" class="d-flex flex-row gap-2 mt-2"></div></div>';
            } else {
                content += '</div>';
            }

            jQuery.confirm({
                title: '',
                content: content,
                theme: 'modern',
                onContentReady: function () {
                    var jc = this;

                    this.$content.find('input[name="deleteOption"]').on('change', function () {
                        var selectedOption = jQuery(this).val();
                        var additionalOptions = jc.$content.find('#additionalOptions');

                        if (selectedOption === 'option3') {
                            additionalOptions.html(
                                `<div class="d-flex flex-column w-100 gap-1">Select Category <select class="w-100 m-0 selectcategory" id="selectBox1">
                                        ${categoryOptions}
                                    </select></div>`
                            );
                        } else {
                            additionalOptions.html('');
                        }
                    });

                    jQuery('input[name="deleteOption"]:checked').trigger('change');
                },
                buttons: {
                    Yes: {
                        btnClass: 'add-button',
                        action: function () {
                            var selectedOption = jQuery('input[name="deleteOption"]:checked').val();
                            if (!selectedOption) {
                                jQuery.alert('Please select an option.');
                                return false;
                            }

                            var parentselectedCategory = null;
                            var subselectedCategory = null;
                            if (selectedOption === 'option3') {
                                parentselectedCategory = jQuery('#selectBox1').find('option:selected').filter(function () {
                                    return jQuery(this).hasClass('level-0');
                                }).val();

                                subselectedCategory = jQuery('#selectBox1').find('option:selected').filter(function () {
                                    return jQuery(this).hasClass('level-1');
                                }).val();
                            }

                            jQuery.ajax({
                                url: BMSI_object.ajax_url,
                                type: "POST",
                                dataType: "JSON",
                                data: {
                                    action: "BMSI_delete_sub_category",
                                    id: id,
                                    delete_option: selectedOption,
                                    parentselectedCategory: parentselectedCategory,
                                    subselectedCategory: subselectedCategory,
                                    news_letter_category_nonce: BMSI_object.nonce,
                                },
                                success: function (response) {
                                    jQuery.confirm({
                                        title: 'Deleted!',
                                        content: response.message,
                                        theme: 'modern',
                                        buttons: {
                                            ok: {
                                                text: 'OK',
                                                btnClass: 'add-button',
                                                action: function () {
                                                    if (response.status == true) {
                                                        location.reload();
                                                    }
                                                }
                                            }
                                        }
                                    });
                                },
                            });
                        }
                    },
                    No: {
                        btnClass: 'add-button',
                    }
                },
            });

        }
    });
}

function send_mail(id) {
    var content = `
        <div class="send-mail">
        <div class='popup'>
            <div class='displayt'>
                <div>
                    <input type='radio' name='emailType' value='user' id='emailTypeUser' checked>
                    <label for='emailTypeUser'>User</label>
                </div>
                <div>
                    <input type='radio' name='emailType' value='newsletter' id='emailTypeNewsletter'>
                    <label for='emailTypeNewsletter'>Contact</label>
                </div>
            </div>
            <div class='diplaym'>
                <div id='userOptions' class="displaycenter gap-3">
                </div>
                <div id='newsletterOptions' class='gap-3 firstAndLastName mb-3' style='display: none;'>
                  <div class="perfectstyle">
                    <label>Category :-</label>
                    <select class='input-groups ml-45' id='newsletterSelect'>
                        <option value='0'>All</option>
                    </select>
                  </div>
                  <div class="perfectstyle">
                    <label>Status :-</label>
                    <div class="d-flex align-items-center gap-3">
                      <div>
                      <input type='radio' name='newsletterStatus' value='1' id='activate' checked>
                      <label for='activate'>Activate</label>
                      </div>
                      <div>
                      <input type='radio' name='newsletterStatus' value='0' id='Inactivate'>
                      <label for='Inactivate'>Inactivate</label>
                      </div>
                    </div>
                  </div>
                </div>
            <div class="displaym gap-3">
            <div class="perfectstyle firstAndLastName ">    
                <label>From Email :-</label>
                <select class='input-groups' id='fromemail'>
                  </select>
            </div>
            <div class='perfectstyle'>
                <label>From Name :-</label>
                <input type='email' class='input-groups' placeholder='Enter From name' id='sendmailname' required>
            </div>
            <div class='perfectstyle'>
                <label>Subject :-</label>
                <input type='text' class='input-groups ml-30' placeholder='Enter Subject' id='sendmailsubject' required>
            </div>
            </div>
        </div></div>`;

    jQuery.confirm({
        title: '',
        content: content,
        theme: 'modern',
        buttons: {
            ok: {
                text: 'Send',
                btnClass: 'add-button send-email',
                action: function () {
                    var emailType = jQuery('input[name="emailType"]:checked').val();
                    var sendmailsubject = jQuery('#sendmailsubject').val();
                    var sendmailFrom = jQuery('#fromemail').val();
                    var sendmailname = jQuery('#sendmailname').val();
                    var newsletterStatus = jQuery('input[name="newsletterStatus"]:checked').val();
                    var parentselectedCategory = jQuery('#newsletterSelect').find('option:selected').filter(function () {
                        return jQuery(this).hasClass('level-0');
                    }).val();

                    var subselectedCategory = jQuery('#newsletterSelect').find('option:selected').filter(function () {
                        return jQuery(this).hasClass('level-1');
                    }).val();

                    if (!sendmailsubject || !sendmailFrom || !sendmailname) {
                        jQuery.alert({
                            title: 'Error!',
                            content: '*All fields are required.',
                            theme: 'modern',
                            buttons: {
                                ok: {
                                    btnClass: 'add-button',
                                }
                            }
                        });
                        return false;
                    }

                    let importButton = jQuery(".send-email");
                    importButton.prop('disabled', true).html('<span class="loader"></span>');

                    if (emailType === "user") {
                        jQuery.ajax({
                            url: ajaxurl,
                            type: "POST",
                            dataType: "JSON",
                            data: {
                                "action": "BMSI_User_send_mail_template",
                                "subject": sendmailsubject,
                                "sender_name":  sendmailname,
                                "sender_mail": sendmailFrom,
                                "template_name": id,
                            },
                            success: function (response) {
                                jQuery.confirm({
                                    title: response.title,
                                    content: response.message,
                                    theme: 'modern',
                                    buttons: {
                                        ok: {
                                            text: 'OK',
                                            btnClass: 'add-button',
                                            action: function () {
                                                importButton.prop('disabled', false).html('Send');
                                                return true;
                                            }
                                        }
                                    }
                                });

                                return false;
                            },
                        });
                    } else {
                        jQuery.ajax({
                            url: ajaxurl,
                            type: "POST",
                            dataType: "JSON",
                            data: {
                                "action": "BMSI_User_send_mail_template_newsletter",
                                "subject": sendmailsubject,
                                "sender_name":  sendmailname,
                                "sender_mail": sendmailFrom,
                                "template_name": id,
                                "parentcategory": parentselectedCategory,
                                "subcategory": subselectedCategory,
                            },
                            success: function (response) {
                                jQuery.confirm({
                                    title: response.title,
                                    content: response.message,
                                    theme: 'modern',
                                    buttons: {
                                        ok: {
                                            text: 'OK',
                                            btnClass: 'add-button',
                                            action: function () {
                                                importButton.prop('disabled', false).html('Send');
                                            }
                                        }
                                    }
                                });
                            },
                        });
                    }
                }
            },
            cancel: {
                btnClass: 'add-button',
            }
        },
        onContentReady: function () {
            var self = this;

            jQuery('input[name="emailType"]').change(function ($) {
                if (jQuery(this).val() === 'user') {
                    jQuery('#userOptions').show();
                    jQuery('#newsletterOptions').hide();
                } else {
                    jQuery('#userOptions').hide();
                    jQuery('#newsletterOptions').show();
                }
            });
            // console.log("test");
            // jQuery('.send-mail').append(
            //     '<div id="LoaderForImportModal" class="text-center m-5">'+
            //         '<div class="spinner-border m-5" style="width: 3rem; height: 3rem;" role="status">'+
            //             '<span class="sr-only">Loading...</span>'+
            //         '</div>'+
            //     '</div>'
            // );
            // jQuery(".send-mail").addClass("add_custome_loader");
            jQuery.ajax({
                url: ajaxurl,
                type: 'POST',
                data: {
                    action: 'get_category',
                },
                success: function (response) {
                    // jQuery('#LoaderForImportModal').remove();
                    var select = jQuery('#newsletterSelect');
                    select.empty().append('<option value="0" class="level-0">All</option>');


                    if (response.success && response.data && response.data.data) {
                        var categories = response.data.data;


                        categories.forEach(function (category) {
                            select.append('<option class="' + category.level + '" value="' + category.id + '">' + category.category_name + '</option>');
                            if (category.subcategories && category.subcategories.length > 0) {
                                category.subcategories.forEach(function (subcategory) {
                                    select.append('<option class="' + subcategory.level + '" value="' + subcategory.id + '">— ' + subcategory.sub_category_name + '</option>');
                                });
                            }
                        });
                    }
                },
            });

            jQuery.ajax({
                url: ajaxurl,
                type: 'POST',
                data: {
                    action: 'get_user_from_email',
                },
                success: function (response) {
                    var select = jQuery('#fromemail');

                    if (response.success && response.data && response.data.data) {
                        var email = response.data.data;

                        email.forEach(function (email) {
                            select.append('<option value="' + email + '">' + email + '</option>');
                        });
                    }
                },
            });
        }
    });
}