<?php

namespace ProApp\baseClasses;

class BMSIProActivate extends BMSIProBase
{
    /**
     * @var string
     */
    public static $warningMessage = '';

    /**
     * function called when plugin activated
     * @return void
     */

    public function __construct()
    {

    }

    public static function activate()
    {
        global $wpdb;
        $tbl_mail_details = $wpdb->prefix . "bmsi_pro_send_mail_details";
        $tbl_news_letter_category = $wpdb->prefix . "bmsi_news_letter_category";
        $tbl_news_letter_tag = $wpdb->prefix . "bmsi_news_letter_tag";
        $tbl_news_letter_sub_category = $wpdb->prefix . "bmsi_news_letter_sub_category";
        $tbl_news_letters_email = $wpdb->prefix . "bmsi_news_letters_email";

        $create_tbl_mail_details = "CREATE TABLE $tbl_mail_details (
            `id` int(25) not null auto_increment,
            `from_mail` varchar(255) not null,
            `from_name` varchar(255) not null,
            `subject` varchar(255) not null,
            `body` text not null,
            `type` varchar(255) not null,
            `createdate` date not null,
            primary key(`id`)
        )";

        $create_tbl_news_letter_category = "CREATE TABLE $tbl_news_letter_category (
            `id` int(25) not null auto_increment,
            `category_name` varchar(255) not null,
            primary key(`id`)
        )";

        $create_tbl_news_letter_tag = "CREATE TABLE $tbl_news_letter_tag (
            `id` int(25) not null auto_increment,
            `tags_name` varchar(255) not null,
            primary key(`id`)
        )";

        $create_tbl_news_letter_sub_category = "CREATE TABLE $tbl_news_letter_sub_category (
            `id` int(25) not null auto_increment,
            `sub_category_name` varchar(255) not null,
            `parent_category_id` varchar(255) not null,
            primary key(`id`)
        )";

        $create_tbl_news_letters_email = "CREATE TABLE $tbl_news_letters_email (
            `id` int(25) not null auto_increment,
            `email` varchar(255) NULL,
            `fname` varchar(255) NULL,
            `lname` varchar(255) NULL,
            `job_title` varchar(255) NULL,
            `company` varchar(255) NULL,
            `birthdate` date NULL,
            `anniversary` date NULL,
            `category` varchar(255) NULL,
            `sub_category` varchar(255) NULL,
            `tag` varchar(255) NULL,
            `status` varchar(255) NULL,
            `createdate` timestamp NULL DEFAULT CURRENT_TIMESTAMP,
            primary key(`id`)
        )";

        require_once ABSPATH . '/wp-admin/includes/upgrade.php';
        maybe_create_table($tbl_mail_details, $create_tbl_mail_details);
        maybe_create_table($tbl_news_letter_category, $create_tbl_news_letter_category);
        maybe_create_table($tbl_news_letter_tag, $create_tbl_news_letter_tag);
        maybe_create_table($tbl_news_letters_email, $create_tbl_news_letters_email);
        maybe_create_table($tbl_news_letter_sub_category, $create_tbl_news_letter_sub_category);

        update_option('BMIS_Pro_activated', false);
    }

    public static function init()
    {
        add_action('init', function () {
            if (!function_exists('get_plugins')) {
                include_once ABSPATH . 'wp-admin/includes/plugin.php';
            }

            $BMSI_plugin = 'bulk-mail-sender/bulk_mail_sender.php';

            if (is_plugin_active($BMSI_plugin)) {
                $plugins = get_plugins();

                if (!empty($plugins[$BMSI_plugin])) {
                    (new BMSIProFilterHandler())->init();
                    return;
                }
            } else {
                self::$warningMessage = esc_html__('Warning:', 'bulk-mailer-pro') . '<b><i>' . esc_html__('Bulk Mail Sender Pro', 'bulk-mailer-pro') . '</i>  </b>' . esc_html__('Requires', 'bulk-mailer-pro') . ' <b> <i>' . esc_html__('Bulk Mail Sender', 'bulk-mailer-pro') . '</i></b>';
                // Send admin notice of error
                add_action('admin_notices', [__CLASS__, 'pluginWarning']);
                // Remove plugin activate message
                if (isset($_GET['activate'])) {
                    unset($_GET['activate']);
                }
                // Deactivate plugin
                deactivate_plugins(BMSI_PRO_PLUGIN_BASENAME);
            }
        });

        add_action('admin_init', [__CLASS__, 'checkPluginActive']);
    }

    public static function pluginWarning()
    {
        $class = 'notice notice-error';
        $message = self::$warningMessage;
        printf('<div class="%1$s"><p>%2$s</p></div>', esc_attr($class), $message);
    }

    public static function checkPluginActive()
    {
        $bulk_mailer = 'bulk-mail-sender/bulk_mail_sender.php';
        // Check lite plugin active
        if (is_plugin_active($bulk_mailer)) {
            $plugins = get_plugins();
            // Check lite plugin version
            if (!empty($plugins[$bulk_mailer])) {

            } else {
                self::$warningMessage = esc_html__('Warning:', 'bulk-mailer-pro') . '<b><i>' . esc_html__('Bulk Mail Sender Pro', 'bulk-mailer-pro') . '</i>  </b>' . esc_html__('Requires', 'bulk-mailer-pro') . ' <b> <i>' . esc_html__('Bulk Mail Sender', 'bulk-mailer-pro') . '</i></b>';
                // Send admin notice of error
                add_action('admin_notices', [__CLASS__, 'pluginWarning']);
                // Remove plugin activate message
                if (isset($_GET['activate'])) {
                    unset($_GET['activate']);
                }
                // Deactivate plugin
                deactivate_plugins(BMSI_PRO_PLUGIN_BASENAME);
            }
        } else {
            self::$warningMessage = esc_html__('Warning: bulk-mailer-pro', 'bulk-mailer-pro') . '<b><b>' . esc_html__(' is deactivate Because bulk-mailer is not active', 'bulk-mailer-pro') . '</b><br> <strong>' . esc_html__('Note:bulk-mail-sender plugin is active still receiving this message then Make sure that bulk-mailer plugin folder is same as " bulk-mailer" in wp-content/plugins.', 'bulk-mailer-pro') . '</strong>';
            // Send admin notice of error
            add_action('admin_notices', [__CLASS__, 'pluginWarning']);
            // Remove plugin activate message
            if (isset($_GET['activate'])) {
                unset($_GET['activate']);
            }
            // Deactivate plugin
            deactivate_plugins(BMSI_PRO_PLUGIN_BASENAME);
        }
    }
}
