<?php

namespace ProApp\baseClasses;

class BMSIProBase
{

    public $plugin_path;

    public $nameSpace;

    public $plugin_url;

    public $plugin;

    public $dbConfig;

    private $pluginPrefix;

    /**
     * class contructor defined variables
     */
    public function __construct()
    {

        add_action('admin_menu', [$this, 'bmsi_pro_admin_page']);
        add_action('admin_head', function () {
            remove_submenu_page('bulk_mail_sender', 'create_template');
        });

        add_action('init', [$this, 'bmsi_alter_query']);

    }

    public function bmsi_alter_query()
    {

        global $wpdb;
        $tbl_mail_details = $wpdb->prefix . "bmsi_pro_send_mail_details";
        $tbl_news_letter_category = $wpdb->prefix . "bmsi_news_letter_category";
        $tbl_news_letter_sub_category = $wpdb->prefix . "bmsi_news_letter_sub_category";
        $tbl_news_letters_email = $wpdb->prefix . "bmsi_news_letters_email";

        if ($wpdb->get_var("SHOW COLUMNS FROM $tbl_news_letters_email LIKE 'sub_category'") !== 'sub_category') {
            $alter_tbl_news_letters_email_two = "ALTER TABLE $tbl_news_letters_email 
            ADD COLUMN `sub_category` varchar(255)";
            $wpdb->query($alter_tbl_news_letters_email_two);
        }

        if ($wpdb->get_var("SHOW COLUMNS FROM $tbl_news_letters_email LIKE 'category'") !== 'category') {
            $alter_tbl_news_letters_email_four = "ALTER TABLE $tbl_news_letters_email 
            ADD COLUMN `category` varchar(255) NOT NULL DEFAULT '1'";
            $wpdb->query($alter_tbl_news_letters_email_four);
        }


        if ($wpdb->get_var("SHOW COLUMNS FROM $tbl_news_letter_category LIKE 'level'") !== 'level') {
            $alter_tbl_news_letter_category_three = "ALTER TABLE $tbl_news_letter_category 
            ADD COLUMN `level` varchar(255) NOT NULL DEFAULT 'level-0'";
            $wpdb->query($alter_tbl_news_letter_category_three);
        }


        if ($wpdb->get_var("SHOW COLUMNS FROM $tbl_news_letter_sub_category LIKE 'level'") !== 'level') {
            $alter_tbl_news_letter_sub_category = "ALTER TABLE $tbl_news_letter_sub_category 
            ADD COLUMN `level` varchar(255) NOT NULL DEFAULT 'level-1'";
            $wpdb->query($alter_tbl_news_letter_sub_category);
        }


        if ($wpdb->get_var("SHOW COLUMNS FROM $tbl_news_letters_email LIKE 'status'") !== 'status') {
            $alter_tbl_news_letters_email = "ALTER TABLE $tbl_news_letters_email 
            ADD COLUMN `status` varchar(50) NOT NULL DEFAULT '1'";
            $wpdb->query($alter_tbl_news_letters_email);
        }

        $default_categories = ['uncategory'];
        foreach ($default_categories as $category_name) {
            $category_exists = $wpdb->get_var($wpdb->prepare("SELECT COUNT(*) FROM $tbl_news_letter_category WHERE category_name = %s", $category_name));
            if (!$category_exists) {
                $wpdb->insert(
                    $tbl_news_letter_category,
                    ['category_name' => $category_name],
                    ['%s']
                );

                $parent_id = $wpdb->insert_id;
            }
        }

        if(!empty($parent_id)){
            $default_sub_categories = [['sub_category_name' => 'uncategory', 'parent_category_id' => $parent_id]];
            foreach ($default_sub_categories as $sub_category) {
                $sub_category_exists = $wpdb->get_var($wpdb->prepare("SELECT COUNT(*) FROM $tbl_news_letter_sub_category WHERE sub_category_name = %s", $sub_category['sub_category_name']));
                if (!$sub_category_exists) {
                    $wpdb->insert(
                        $tbl_news_letter_sub_category,
                        $sub_category,
                        ['%s', '%d']
                    );
                }
            }

        }

    }

    public function bmsi_pro_admin_page()
    {

        add_submenu_page(
            'bulk_mail_sender',
            __('Bulk Mail Sender Send Mail', 'bulk-mail-sender-pro'),
            __('Create Template', 'bulk-mail-sender-pro'),
            'manage_options',
            'create_template',
            [$this, 'bmsi_pro_admin_create_template_submenu_page'],
        );

    }



    public function bmsi_pro_admin_create_template_submenu_page()
    {
        require_once (BMSI_PRO_DIR_PATH . 'templates/BMSICreateTemplate.php');
    }

    /**
     * function to get plugin namespace
     * @return string
     */
    public function get_namespace()
    {
        return $this->nameSpace;
    }

    /**
     * function to get plugin prefix
     * @return string
     */
    protected function getPrefix()
    {
        return BMSI_PRO_PREFIX;
    }

    /**
     * function to get plugin prefix
     * @return string
     */
    protected function getPluginPrefix()
    {
        return $this->pluginPrefix;
    }

}

